@@ -64,16 +64,15 @@ static void drop_locale_dir (char *locale_dir);
 static void
 i18n_init (void)
 {
+#ifdef ENABLE_NLS
   char *locale_dir;
 
-#ifdef ENABLE_NLS
 # ifdef HAVE_LC_MESSAGES
   setlocale (LC_TIME, "");
   setlocale (LC_MESSAGES, "");
 # else
   setlocale (LC_ALL, "" );
 # endif
-#endif
 
   locale_dir = get_locale_dir ();
   if (locale_dir)
@@ -82,6 +81,7 @@ i18n_init (void)
       drop_locale_dir (locale_dir);
     }
   textdomain (PACKAGE);
+#endif
 }
 
 
@@ -215,7 +215,7 @@ get_locale_dir (void)
   instdir = read_w32_registry_string ("HKEY_LOCAL_MACHINE", REGKEY,
 				      "Install Directory");
   if (!instdir)
-    return;
+    return NULL;
   
   /* Build the key: "<instdir>/share/locale".  */
 #define SLDIR "\\share\\locale"
@@ -223,7 +223,7 @@ get_locale_dir (void)
   if (!dname)
     {
       free (instdir);
-      return;
+      return NULL;
     }
   p = dname;
   strcpy (p, instdir);
@@ -451,11 +451,19 @@ main (int argc, char *argv[])
 
   i18n_init ();
 
+
   if (argc == 1)
     {
-      fprintf (stderr, _("Usage: %s GPG-ERROR [...]\n"), argv[0]);
+      fprintf (stderr, _("Usage: %s GPG-ERROR [...]\n"), 
+               strrchr (argv[0],'/')? (strrchr (argv[0], '/')+1): argv[0]);
       exit (1);
     }
+  else if (argc == 2 && !strcmp (argv[1], "--version"))
+    {
+      fputs ("gpg-error (" PACKAGE_NAME ") " PACKAGE_VERSION "\n", stdout);
+      exit (0);
+    }
+
 
   while (i < argc)
     {
